##  Introduction
SAP LeanIX diagram offers SAP Business Technology Platform (BTP) reference architecture patterns as templates. Using the templates, you can easily design, customize, and communicate SAP BTP solution architectures that are in alignment with SAP best practices.
The SAP BTP reference architecture templates integrate seamlessly with the SAP LeanIX inventory, as shapes within the templates can be linked to fact sheets. This ensures that the diagrams you create using templates are accurate and up-to-date with your organization's real architecture data.
